@@ -1,8 +1,8 @@
 #![macro_use]
-use fugle::crawler;
-use fugle::schema::{FugleError, Response, Result};
 use std::{sync::mpsc, thread, time::Duration};
 
+use fugle::{errors::FugleError, schema::Result};
+
 macro_rules! assert_err {
     ($expression:expr, $($pattern:tt)+) => {
         match $expression {
@@ -12,16 +12,6 @@ macro_rules! assert_err {
     }
 }
 
-macro_rules! fetch_enum {
-    ($enum:path, $expr:expr) => {{
-        if let $enum(item) = $expr {
-            item
-        } else {
-            panic!("failed to extract enum: {:?}", $expr)
-        }
-    }};
-}
-
 pub(crate) fn timeout_after<T, F>(d: Duration, f: F) -> T
 where
     T: Send + 'static,
@@ -47,17 +37,6 @@ fn test_assert_err() {
     assert_err!(some_fn(), Err(FugleError::ResourceNotFound));
 }
 
-#[test]
-fn test_fetch_enum() {
-    let res = crawler::IntradayBuilder::new()
-        .build()
-        .chart("2884")
-        .call()
-        .unwrap();
-    let v = fetch_enum!(Response::Chart, res);
-    assert_eq!(v.data.info.symbol_id, "2884");
-}
-
 #[test]
 #[should_panic]
 fn test_timeout_after() {
